@@ -19,10 +19,12 @@ try:
     # Python 3
     import urllib.parse as urlparse
     from urllib.parse import urlencode
+    string_types = str
 except ImportError:
     # Python 2
     import urlparse
     from urllib import urlencode
+    string_types = basestring
 
 
 # import request objects from various frameworks, if available
@@ -112,7 +114,7 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.7.0'
+VERSION = '0.7.1'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
@@ -626,16 +628,25 @@ def _scrub_request_params(params, replacement_character='*'):
     (replaced with astrickses)
     """
     scrub_fields = set(SETTINGS['scrub_fields'])
-    params = dict(params)
 
-    for k, v in params.items():
-        if k.lower() in scrub_fields:
-            if isinstance(v, list):
-                params[k] = [replacement_character * len(x) for x in v]
+    def _scrub(params, k=None):
+        if k is not None and k.lower() in scrub_fields:
+            if isinstance(params, string_types):
+                return replacement_character * len(params)
+            elif isinstance(params, list):
+                return [_scrub(v, k) for v in params]
+            elif isinstance(params, dict):
+                return {replacement_character: replacement_character}
             else:
-                params[k] = replacement_character * len(v)
+                return replacement_character
+        elif isinstance(params, dict):
+            return dict((_k,  _scrub(v, _k)) for _k, v in params.items())
+        elif isinstance(params, list):
+            return [_scrub(x, k) for x in params]
+        else:
+            return params
 
-    return params
+    return _scrub(params)
 
 
 def _build_webob_request_data(request):
@@ -703,7 +714,7 @@ def _build_werkzeug_request_data(request):
     }
 
     if request.get_json():
-        request_data['body'] = request.data
+        request_data['body'] = _scrub_request_params(request.json)
 
     return request_data
 
